<?php
/**
 * The Classic template to display the content
 *
 * Used for index/archive/search.
 *
 * @package WordPress
 * @subpackage MAXCUBE
 * @since MAXCUBE 1.0
 */

$maxcube_template_args = get_query_var('maxcube_template_args');
if (is_array($maxcube_template_args)) {
	$maxcube_columns = empty($maxcube_template_args['columns']) ? 1 : max(1, min(3, $maxcube_template_args['columns']));
	$maxcube_blog_style = array($maxcube_template_args['type'], $maxcube_columns);
} else {
	$maxcube_blog_style = explode('_', maxcube_get_theme_option('blog_style'));
	$maxcube_columns = empty($maxcube_blog_style[1]) ? 1 : max(1, min(3, $maxcube_blog_style[1]));
}
$maxcube_expanded = !maxcube_sidebar_present() && maxcube_is_on(maxcube_get_theme_option('expand_content'));
$maxcube_post_format = get_post_format();
$maxcube_post_format = empty($maxcube_post_format) ? 'standard' : str_replace('post-format-', '', $maxcube_post_format);
$maxcube_animation = maxcube_get_theme_option('blog_animation');

?><article id="post-<?php the_ID(); ?>" <?php
	post_class( 'post_item'
				. ' post_layout_chess'
				. ' post_layout_chess_'.esc_attr($maxcube_columns)
				. ' post_format_'.esc_attr($maxcube_post_format)
				. (!empty($maxcube_template_args['slider']) ? ' slider-slide swiper-slide' : '')
				);
	echo (!maxcube_is_off($maxcube_animation) && empty($maxcube_template_args['slider']) ? ' data-animation="'.esc_attr(maxcube_get_animation_classes($maxcube_animation)).'"' : '');
?>>

	<?php
	// Add anchor
	if ($maxcube_columns == 1 && !is_array($maxcube_template_args) && shortcode_exists('trx_sc_anchor')) {
		echo do_shortcode('[trx_sc_anchor id="post_'.esc_attr(get_the_ID()).'" title="'.esc_attr(get_the_title()).'" icon="'.esc_attr(maxcube_get_post_icon()).'"]');
	}

	// Sticky label
	if ( is_sticky() && !is_paged() ) {
		?><span class="post_label label_sticky"></span><?php
	}

	// Featured image
	$maxcube_hover = !empty($maxcube_template_args['hover']) && !maxcube_is_inherit($maxcube_template_args['hover'])
						? $maxcube_template_args['hover'] 
						: maxcube_get_theme_option('image_hover');
	maxcube_show_post_featured( array(
											'class' => $maxcube_columns == 1 && !is_array($maxcube_template_args) ? 'maxcube-full-height' : '',
											'singular' => false,
											'hover' => $maxcube_hover,
											'no_links' => !empty($maxcube_template_args['no_links']),
											'show_no_image' => true,
											'thumb_bg' => true,
											'thumb_size' => maxcube_get_thumb_size(
																	strpos(maxcube_get_theme_option('body_style'), 'full')!==false
																		? ( $maxcube_columns > 1 ? 'huge' : 'original' )
																		: (	$maxcube_columns > 2 ? 'big' : 'huge')
																	)
											) 
										);

	?><div class="post_inner"><div class="post_inner_content"><?php 

		?><div class="post_header entry-header"><?php 
			do_action('maxcube_action_before_post_title'); 

			// Post title
			if (empty($maxcube_template_args['no_links']))
				the_title( sprintf( '<h3 class="post_title entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h3>' );
			else
				the_title( '<h3 class="post_title entry-title">', '</h3>' );
			
			do_action('maxcube_action_before_post_meta'); 

			// Post meta
			$maxcube_components = maxcube_array_get_keys_by_value(maxcube_get_theme_option('meta_parts'));
			$maxcube_counters = maxcube_array_get_keys_by_value(maxcube_get_theme_option('counters'));
			$maxcube_post_meta = empty($maxcube_components) || in_array($maxcube_hover, array('border', 'pull', 'slide', 'fade'))
										? '' 
										: maxcube_show_post_meta(apply_filters('maxcube_filter_post_meta_args', array(
												'components' => $maxcube_components,
												'counters' => $maxcube_counters,
												'seo' => false,
												'echo' => false
												), $maxcube_blog_style[0], $maxcube_columns)
											);
			maxcube_show_layout($maxcube_post_meta);
		?></div><!-- .entry-header -->
	
		<div class="post_content entry-content"><?php
			if (empty($maxcube_template_args['hide_excerpt'])) {
				?><div class="post_content_inner"><?php
					if (has_excerpt()) {
						the_excerpt();
					} else if (strpos(get_the_content('!--more'), '!--more')!==false) {
						the_content( '' );
					} else if (in_array($maxcube_post_format, array('link', 'aside', 'status'))) {
						the_content();
					} else if ($maxcube_post_format == 'quote') {
						if (($quote = maxcube_get_tag(get_the_content(), '<blockquote>', '</blockquote>'))!='')
							maxcube_show_layout(wpautop($quote));
						else
							the_excerpt();
					} else if (substr(get_the_content(), 0, 4)!='[vc_') {
						the_excerpt();
					}
				?></div><?php
			}
			// Post meta
			if (in_array($maxcube_post_format, array('link', 'aside', 'status', 'quote'))) {
				maxcube_show_layout($maxcube_post_meta);
			}
			// More button
			if ( empty($maxcube_template_args['no_links']) && !in_array($maxcube_post_format, array('link', 'aside', 'status', 'quote')) ) {
				?><p><a class="more-link" href="<?php echo esc_url(get_permalink()); ?>"><?php esc_html_e('Read More', 'maxcube'); ?></a></p><?php
			}
			?>
		</div><!-- .entry-content -->

	</div></div><!-- .post_inner -->

</article>