<?php
/**
 * The Gallery template to display posts
 *
 * Used for index/archive/search.
 *
 * @package WordPress
 * @subpackage MAXCUBE
 * @since MAXCUBE 1.0
 */

$maxcube_template_args = get_query_var('maxcube_template_args');
if (is_array($maxcube_template_args)) {
	$maxcube_columns = empty($maxcube_template_args['columns']) ? 2 : max(2, $maxcube_template_args['columns']);
	$maxcube_blog_style = array($maxcube_template_args['type'], $maxcube_columns);
} else {
	$maxcube_blog_style = explode('_', maxcube_get_theme_option('blog_style'));
	$maxcube_columns = empty($maxcube_blog_style[1]) ? 2 : max(2, $maxcube_blog_style[1]);
}
$maxcube_post_format = get_post_format();
$maxcube_post_format = empty($maxcube_post_format) ? 'standard' : str_replace('post-format-', '', $maxcube_post_format);
$maxcube_animation = maxcube_get_theme_option('blog_animation');
$maxcube_image = wp_get_attachment_image_src( get_post_thumbnail_id(get_the_ID()), 'full' );

?><article id="post-<?php the_ID(); ?>" <?php
	post_class( 'post_item'
				. ' post_layout_portfolio'
				. ' post_layout_gallery'
				. ' post_layout_gallery_'.esc_attr($maxcube_columns)
				. ' post_format_'.esc_attr($maxcube_post_format)
				. (!empty($maxcube_template_args['slider']) ? ' slider-slide swiper-slide' : '')
			);
	echo (!maxcube_is_off($maxcube_animation) && empty($maxcube_template_args['slider']) ? ' data-animation="'.esc_attr(maxcube_get_animation_classes($maxcube_animation)).'"' : '');
	?>
	data-size="<?php if (!empty($maxcube_image[1]) && !empty($maxcube_image[2])) echo intval($maxcube_image[1]) .'x' . intval($maxcube_image[2]); ?>"
	data-src="<?php if (!empty($maxcube_image[0])) echo esc_url($maxcube_image[0]); ?>"
><?php

	// Sticky label
	if ( is_sticky() && !is_paged() ) {
		?><span class="post_label label_sticky"></span><?php
	}

	// Featured image
	$maxcube_image_hover = 'icon';	
	if (in_array($maxcube_image_hover, array('icons', 'zoom'))) $maxcube_image_hover = 'dots';
	$maxcube_components = maxcube_array_get_keys_by_value(maxcube_get_theme_option('meta_parts'));
	$maxcube_counters = maxcube_array_get_keys_by_value(maxcube_get_theme_option('counters'));
	maxcube_show_post_featured(array(
		'hover' => $maxcube_image_hover,
		'singular' => false,
		'no_links' => !empty($maxcube_template_args['no_links']),
		'thumb_size' => maxcube_get_thumb_size( strpos(maxcube_get_theme_option('body_style'), 'full')!==false || $maxcube_columns < 3 ? 'masonry-big' : 'masonry' ),
		'thumb_only' => true,
		'show_no_image' => true,
		'post_info' => '<div class="post_details">'
							. '<h2 class="post_title">'
								. (empty($maxcube_template_args['no_links']) 
									? '<a href="'.esc_url(get_permalink()).'">' . esc_html(get_the_title()) . '</a>'
									: esc_html(get_the_title())
									)
							. '</h2>'
							. '<div class="post_description">'
								. (!empty($maxcube_components)
									? maxcube_show_post_meta(apply_filters('maxcube_filter_post_meta_args', array(
											'components' => $maxcube_components,
											'counters' => $maxcube_counters,
											'seo' => false,
											'echo' => false
											), $maxcube_blog_style[0], $maxcube_columns))
									: ''
									)
								. (empty($maxcube_template_args['hide_excerpt'])
									? '<div class="post_description_content">' . get_the_excerpt() . '</div>'
									: ''
									)
								. (empty($maxcube_template_args['no_links']) 
									? '<a href="'.esc_url(get_permalink()).'" class="theme_button post_readmore"><span class="post_readmore_label">' . esc_html__('Learn more', 'maxcube') . '</span></a>' 
									: ''
									)
							. '</div>'
						. '</div>'
	));
?></article>