<?php
/**
 * The default template to display the content of the single post, page or attachment
 *
 * Used for index/archive/search.
 *
 * @package WordPress
 * @subpackage MAXCUBE
 * @since MAXCUBE 1.0
 */

$maxcube_seo = maxcube_is_on(maxcube_get_theme_option('seo_snippets'));
?>

<article id="post-<?php the_ID(); ?>" <?php post_class( 'post_item_single post_type_'.esc_attr(get_post_type()) 
												. ' post_format_'.esc_attr(str_replace('post-format-', '', get_post_format())) 
												);
		if ($maxcube_seo) {
			?> itemscope="itemscope" 
			   itemprop="articleBody" 
			   itemtype="http://schema.org/<?php echo esc_attr(maxcube_get_markup_schema()); ?>" 
			   itemid="<?php echo esc_url(get_the_permalink()); ?>"
			   content="<?php echo esc_attr(get_the_title()); ?>"<?php
		}
?>><?php

    ?>
    <div class="post-conters"><?php
        $dt = apply_filters('maxcube_filter_get_post_date', maxcube_get_date('', 'j M'));
        $date = explode(' ', $dt);
        if (count($date) > 1) {
            $date[0] = '<span class="post-date">' . $date[0] . '</span> <span class="post-all">';
            $date[count($date) - 1] = ' <span class="post-day">' . $date[count($date) - 1] . '</span></span>';
        }
        $dt = '';
        foreach ($date as $d) {
            $dt = $dt . ' ' . $d;
        }
        if (!empty($dt)) {
            ?>
            <div class="post_meta_item post_date"><?php echo wp_kses_post($dt); ?></div>
            <?php
        }
        ?></div><?php

	do_action('maxcube_action_before_post_data'); 

	// Structured data snippets
	if ($maxcube_seo)
		get_template_part( apply_filters('maxcube_filter_get_template_part', 'templates/seo') );

	// Featured image
	if ( maxcube_is_off(maxcube_get_theme_option('hide_featured_on_single'))
			&& !maxcube_sc_layouts_showed('featured') 
			&& strpos(get_the_content(), '[trx_widget_banner]')===false) {
		do_action('maxcube_action_before_post_featured'); 
		maxcube_show_post_featured();
		do_action('maxcube_action_after_post_featured'); 
	} else if (has_post_thumbnail()) {
		?><meta itemprop="image" itemtype="http://schema.org/ImageObject" content="<?php echo esc_url(wp_get_attachment_url(get_post_thumbnail_id())); ?>"><?php
	}

    maxcube_show_post_meta(apply_filters('maxcube_filter_post_meta_args', array(
            'components' => 'categories',
            'counters' => '',
            'seo' => false
        ), 'excerpt', 1)
    );

	// Title and post meta
	if ( (!maxcube_sc_layouts_showed('title')) && !in_array(get_post_format(), array('link', 'aside', 'status', 'quote')) ) {
		do_action('maxcube_action_before_post_title'); 
		?>
		<div class="post_header post_header_single entry-header">
			<?php
			// Post title
			if (!maxcube_sc_layouts_showed('title')) {
				the_title( '<h3 class="post_title entry-title"'.($maxcube_seo ? ' itemprop="headline"' : '').'>', '</h3>' );
			}
			?>
		</div><!-- .post_header -->
		<?php
		do_action('maxcube_action_after_post_title'); 
	}

	do_action('maxcube_action_before_post_content'); 

	// Post content
	?>
	<div class="post_content post_content_single entry-content" itemprop="mainEntityOfPage">
		<?php
		the_content( );

		do_action('maxcube_action_before_post_pagination'); 

		wp_link_pages( array(
			'before'      => '<div class="page_links"><span class="page_links_title">' . esc_html__( 'Pages:', 'maxcube' ) . '</span>',
			'after'       => '</div>',
			'link_before' => '<span>',
			'link_after'  => '</span>',
			'pagelink'    => '<span class="screen-reader-text">' . esc_html__( 'Page', 'maxcube' ) . ' </span>%',
			'separator'   => '<span class="screen-reader-text">, </span>',
		) );

        // Post meta
        if (!maxcube_sc_layouts_showed('postmeta') && maxcube_is_on(maxcube_get_theme_option('show_post_meta'))) {
            maxcube_show_post_meta(apply_filters('maxcube_filter_post_meta_args', array(
                    'components' => maxcube_array_get_keys_by_value(maxcube_get_theme_option('meta_parts')),
                    'counters' => maxcube_array_get_keys_by_value(maxcube_get_theme_option('counters')),
                    'seo' => maxcube_is_on(maxcube_get_theme_option('seo_snippets'))
                ), 'single', 1)
            );
        }

		// Taxonomies and share
		if ( is_single() && !is_attachment() ) {
			
			do_action('maxcube_action_before_post_meta'); 
			
			// Post rating
			do_action('trx_addons_action_post_rating', array(
				'class' => 'single_post_rating',
				'rating_text_template' => esc_html__('Post rating: {{X}} from {{Y}} (according {{V}})', 'maxcube')
			));
			
			?><div class="post_meta post_meta_single"><?php
				
				// Post taxonomies
				the_tags( '<span class="post_meta_item post_tags"><span class="post_meta_label">'.esc_html__('Tags:', 'maxcube').'</span> ', ', ', '</span>' );

				// Share
				if (maxcube_is_on(maxcube_get_theme_option('show_share_links'))) {
					maxcube_show_share_links(array(
							'type' => 'block',
							'caption' => esc_html__('Share:','maxcube'),
							'before' => '<span class="post_meta_item post_share">',
							'after' => '</span>'
						));
				}
			?></div><?php

			do_action('maxcube_action_after_post_meta'); 
		}
		?>
	</div><!-- .entry-content -->
	

	<?php
	do_action('maxcube_action_after_post_content'); 

	// Author bio
	if ( maxcube_get_theme_option('show_author_info')==1 && is_single() && !is_attachment() && get_the_author_meta( 'description' ) ) {
		do_action('maxcube_action_before_post_author'); 
		get_template_part( apply_filters('maxcube_filter_get_template_part', 'templates/author-bio') );
		do_action('maxcube_action_after_post_author'); 
	}

	do_action('maxcube_action_after_post_data'); 
	?>
</article>
