<?php
/**
 * The template for homepage posts with "Portfolio" style
 *
 * @package WordPress
 * @subpackage MAXCUBE
 * @since MAXCUBE 1.0
 */

maxcube_storage_set('blog_archive', true);

get_header(); 

if (have_posts()) {

	maxcube_blog_archive_start();

	$maxcube_stickies = is_home() ? get_option( 'sticky_posts' ) : false;
	$maxcube_sticky_out = maxcube_get_theme_option('sticky_style')=='columns' 
							&& is_array($maxcube_stickies) && count($maxcube_stickies) > 0 && get_query_var( 'paged' ) < 1;
	
	// Show filters
	$maxcube_cat = maxcube_get_theme_option('parent_cat');
	$maxcube_post_type = maxcube_get_theme_option('post_type');
	$maxcube_taxonomy = maxcube_get_post_type_taxonomy($maxcube_post_type);
	$maxcube_show_filters = maxcube_get_theme_option('show_filters');
	$maxcube_tabs = array();
	if (!maxcube_is_off($maxcube_show_filters)) {
		$maxcube_args = array(
			'type'			=> $maxcube_post_type,
			'child_of'		=> $maxcube_cat,
			'orderby'		=> 'name',
			'order'			=> 'ASC',
			'hide_empty'	=> 1,
			'hierarchical'	=> 0,
			'taxonomy'		=> $maxcube_taxonomy,
			'pad_counts'	=> false
		);
		$maxcube_portfolio_list = get_terms($maxcube_args);
		if (is_array($maxcube_portfolio_list) && count($maxcube_portfolio_list) > 0) {
			$maxcube_tabs[$maxcube_cat] = esc_html__('All', 'maxcube');
			foreach ($maxcube_portfolio_list as $maxcube_term) {
				if (isset($maxcube_term->term_id)) $maxcube_tabs[$maxcube_term->term_id] = $maxcube_term->name;
			}
		}
	}
	if (count($maxcube_tabs) > 0) {
		$maxcube_portfolio_filters_ajax = true;
		$maxcube_portfolio_filters_active = $maxcube_cat;
		$maxcube_portfolio_filters_id = 'portfolio_filters';
		?>
		<div class="portfolio_filters maxcube_tabs maxcube_tabs_ajax">
			<ul class="portfolio_titles maxcube_tabs_titles">
				<?php
				foreach ($maxcube_tabs as $maxcube_id=>$maxcube_title) {
					?><li><a href="<?php echo esc_url(maxcube_get_hash_link(sprintf('#%s_%s_content', $maxcube_portfolio_filters_id, $maxcube_id))); ?>" data-tab="<?php echo esc_attr($maxcube_id); ?>"><?php echo esc_html($maxcube_title); ?></a></li><?php
				}
				?>
			</ul>
			<?php
			$maxcube_ppp = maxcube_get_theme_option('posts_per_page');
			if (maxcube_is_inherit($maxcube_ppp)) $maxcube_ppp = '';
			foreach ($maxcube_tabs as $maxcube_id=>$maxcube_title) {
				$maxcube_portfolio_need_content = $maxcube_id==$maxcube_portfolio_filters_active || !$maxcube_portfolio_filters_ajax;
				?>
				<div id="<?php echo esc_attr(sprintf('%s_%s_content', $maxcube_portfolio_filters_id, $maxcube_id)); ?>"
					class="portfolio_content maxcube_tabs_content"
					data-blog-template="<?php echo esc_attr(maxcube_storage_get('blog_template')); ?>"
					data-blog-style="<?php echo esc_attr(maxcube_get_theme_option('blog_style')); ?>"
					data-posts-per-page="<?php echo esc_attr($maxcube_ppp); ?>"
					data-post-type="<?php echo esc_attr($maxcube_post_type); ?>"
					data-taxonomy="<?php echo esc_attr($maxcube_taxonomy); ?>"
					data-cat="<?php echo esc_attr($maxcube_id); ?>"
					data-parent-cat="<?php echo esc_attr($maxcube_cat); ?>"
					data-need-content="<?php echo (false===$maxcube_portfolio_need_content ? 'true' : 'false'); ?>"
				>
					<?php
					if ($maxcube_portfolio_need_content) 
						maxcube_show_portfolio_posts(array(
							'cat' => $maxcube_id,
							'parent_cat' => $maxcube_cat,
							'taxonomy' => $maxcube_taxonomy,
							'post_type' => $maxcube_post_type,
							'page' => 1,
							'sticky' => $maxcube_sticky_out
							)
						);
					?>
				</div>
				<?php
			}
			?>
		</div>
		<?php
	} else {
		maxcube_show_portfolio_posts(array(
			'cat' => $maxcube_cat,
			'parent_cat' => $maxcube_cat,
			'taxonomy' => $maxcube_taxonomy,
			'post_type' => $maxcube_post_type,
			'page' => 1,
			'sticky' => $maxcube_sticky_out
			)
		);
	}

	maxcube_blog_archive_end();

} else {

	if ( is_search() )
		get_template_part( apply_filters('maxcube_filter_get_template_part', 'content', 'none-search'), 'none-search' );
	else
		get_template_part( apply_filters('maxcube_filter_get_template_part', 'content', 'none-archive'), 'none-archive' );

}

get_footer();
?>