<?php
/* Contact Form 7 support functions
------------------------------------------------------------------------------- */

// Theme init priorities:
// 9 - register other filters (for installer, etc.)
if (!function_exists('maxcube_cf7_theme_setup9')) {
	add_action( 'after_setup_theme', 'maxcube_cf7_theme_setup9', 9 );
	function maxcube_cf7_theme_setup9() {
		
		add_filter( 'maxcube_filter_merge_scripts',	'maxcube_cf7_merge_scripts');
		add_filter( 'maxcube_filter_merge_styles',	'maxcube_cf7_merge_styles' );

		if (maxcube_exists_cf7()) {
			add_action( 'wp_enqueue_scripts',		'maxcube_cf7_frontend_scripts', 1100 );
		}

		if (is_admin()) {
			add_filter( 'maxcube_filter_tgmpa_required_plugins',	'maxcube_cf7_tgmpa_required_plugins' );
		}
	}
}

// Filter to add in the required plugins list
if ( !function_exists( 'maxcube_cf7_tgmpa_required_plugins' ) ) {
	//Handler of the add_filter('maxcube_filter_tgmpa_required_plugins',	'maxcube_cf7_tgmpa_required_plugins');
	function maxcube_cf7_tgmpa_required_plugins($list=array()) {
		if (maxcube_storage_isset('required_plugins', 'contact-form-7')) {
			// CF7 plugin
			$list[] = array(
					'name' 		=> maxcube_storage_get_array('required_plugins', 'contact-form-7'),
					'slug' 		=> 'contact-form-7',
					'required' 	=> false
			);
// CF7 extension - datepicker
            if (!MAXCUBE_THEME_FREE) {
                $params = array(
                    'name' 		=> esc_html__('Contact Form 7 Datepicker', 'maxcube'),
                    'slug' 		=> 'contact-form-7-datepicker',
                    'required' 	=> false
                );
                $path = maxcube_get_file_dir('plugins/contact-form-7/contact-form-7-datepicker.zip');
                if ($path != '')
                    $params['source'] = $path;
                $list[] = $params;
            }


        }
		return $list;
	}
}



// Check if cf7 installed and activated
if ( !function_exists( 'maxcube_exists_cf7' ) ) {
	function maxcube_exists_cf7() {
		return class_exists('WPCF7');
	}
}

// Enqueue custom scripts
if ( !function_exists( 'maxcube_cf7_frontend_scripts' ) ) {
	//Handler of the add_action( 'wp_enqueue_scripts', 'maxcube_cf7_frontend_scripts', 1100 );
	function maxcube_cf7_frontend_scripts() {
		if (maxcube_exists_cf7()) {
			if (maxcube_is_on(maxcube_get_theme_option('debug_mode')) && ($maxcube_url = maxcube_get_file_url('plugins/contact-form-7/contact-form-7.js')) != '')
				wp_enqueue_script( 'maxcube-cf7', $maxcube_url, array('jquery'), null, true );
		}
	}
}
	
// Merge custom scripts
if ( !function_exists( 'maxcube_cf7_merge_scripts' ) ) {
	//Handler of the add_filter('maxcube_filter_merge_scripts', 'maxcube_cf7_merge_scripts');
	function maxcube_cf7_merge_scripts($list) {
		if (maxcube_exists_cf7()) {
			$list[] = 'plugins/contact-form-7/contact-form-7.js';
		}
		return $list;
	}
}

// Merge custom styles
if ( !function_exists( 'maxcube_cf7_merge_styles' ) ) {
	//Handler of the add_filter('maxcube_filter_merge_styles', 'maxcube_cf7_merge_styles');
	function maxcube_cf7_merge_styles($list) {
		if (maxcube_exists_cf7()) {
			$list[] = 'plugins/contact-form-7/_contact-form-7.scss';
		}
		return $list;
	}
}
?>